=======
Credits
=======

Contributors
* Adam Marcus <marcua@marcua.net>

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.
